import humanize
import datetime
from flask import current_app
from zoneinfo import ZoneInfo
import logging

log = logging.getLogger(__name__)


def htime(ts):
    if ts:
        dt = datetime.datetime.fromtimestamp(ts)
        return humanize.naturaltime(dt)


def htime_dt(dt):
    if dt:
        try:
            return humanize.naturaltime(dt)
        except ValueError:
            return "Never"


def hdate(ts):
    if ts:
        dt = datetime.datetime.fromtimestamp(ts)
        return humanize.naturaldate(dt)


def hdate_dt(dt):
    if dt:
        try:
            return humanize.naturaldate(dt)
        except ValueError:
            return "Never"


def fmt_timestamp(ts):
    with current_app.app_context():
        tz = ZoneInfo(current_app.config['APP_TZ'])
        if ts:
            local_ts = datetime.datetime.fromtimestamp(ts, tz)
            return "%s %s" % (local_ts.strftime('%Y-%m-%d %H:%M:%S'),
                              local_ts.tzname())


def fmt_datetime(dt):
    with current_app.app_context():
        tz = ZoneInfo(current_app.config['APP_TZ'])
        if dt:
            try:
                local_ts = dt.fromtimestamp(dt.timestamp(), tz)
            except OverflowError:
                return "Never"
            return "%s %s" % (local_ts.strftime('%Y-%m-%d %H:%M:%S'),
                              local_ts.tzname())


def fancyBool(bool_):
    if bool_:
        return '<span style="color: green">&#x2714;</span>'
    else:
        return '<span style="color: red">&#x2718;</span>'


def fancyOnline(online):
    return ["offline", "online"][online]


# A list of all of the template_filter functions to add in `init_app`
FILTERS = [hdate,
           hdate_dt,
           htime,
           htime_dt,
           fmt_timestamp,
           fmt_datetime,
           fancyBool,
           fancyOnline]


def init_app(app):
    """Register the template filters with an app instance"""
    log.debug("filters init")
    for func in FILTERS:
        app.jinja_env.filters[func.__name__] = func
